==> local_deep_research-0.4.3-py3-none-any.whl: local_deep_research/benchmarks/datasets/utils.py <==
"""
Utility functions for dataset handling.

This module provides utility functions for common dataset operations like
decryption, encoding detection, etc.
"""

import base64
import hashlib
import logging
from typing import Dict, Any

logger = logging.getLogger(__name__)


def derive_key(password: str, length: int) -> bytes:
    """Derive a fixed-length key from the password using SHA256."""
    hasher = hashlib.sha256()
    hasher.update(password.encode())
    key = hasher.digest()
    return key * (length // len(key)) + key[: length % len(key)]


def decrypt(ciphertext_b64: str, password: str) -> str:
    """
    Decrypt base64-encoded ciphertext with XOR.
    Uses multiple approaches to handle different encoding formats.
    """
    # Skip decryption for non-encoded strings
    if not isinstance(ciphertext_b64, str) or len(ciphertext_b64) < 8:
        return ciphertext_b64
        
    # Skip if the string doesn't look like base64
    if not all(c in 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/=' for c in ciphertext_b64):
        return ciphertext_b64
    
    # Attempt standard decryption
    try:
        encrypted = base64.b64decode(ciphertext_b64)
        key = derive_key(password, len(encrypted))
        decrypted = bytes(a ^ b for a, b in zip(encrypted, key))
        
        # Check if the result looks like valid text
        result = decrypted.decode('utf-8', errors='replace')
        
        # Heuristic check - if the decrypted text is mostly ASCII and contains spaces
        if all(32 <= ord(c) < 127 for c in result[:50]) and ' ' in result[:50]:
            logger.debug(f"Successfully decrypted with standard method: {result[:50]}...")
            return result
    except Exception as e:
        logger.debug(f"Standard decryption failed: {str(e)}")
    
    # Alternative method - try using just the first part of the password
    try:
        if len(password) > 30:
            alt_password = password.split()[0]  # Use first word
            encrypted = base64.b64decode(ciphertext_b64)
            key = derive_key(alt_password, len(encrypted))
            decrypted = bytes(a ^ b for a, b in zip(encrypted, key))
            
            result = decrypted.decode('utf-8', errors='replace')
            if all(32 <= ord(c) < 127 for c in result[:50]) and ' ' in result[:50]:
                logger.debug(f"Successfully decrypted with alternate method 1: {result[:50]}...")
                return result
    except Exception:
        pass
    
    # Alternative method 2 - try using the GUID part
    try:
        if "GUID" in password:
            guid_part = password.split("GUID")[1].strip()
            encrypted = base64.b64decode(ciphertext_b64)
            key = derive_key(guid_part, len(encrypted))
            decrypted = bytes(a ^ b for a, b in zip(encrypted, key))
            
            result = decrypted.decode('utf-8', errors='replace')
            if all(32 <= ord(c) < 127 for c in result[:50]) and ' ' in result[:50]:
                logger.debug(f"Successfully decrypted with GUID method: {result[:50]}...")
                return result
    except Exception:
        pass
    
    # Alternative method 3 - hardcoded key for BrowseComp
    try:
        hardcoded_key = "MHGGF2022!"  # Known key for BrowseComp dataset
        encrypted = base64.b64decode(ciphertext_b64)
        key = derive_key(hardcoded_key, len(encrypted))
        decrypted = bytes(a ^ b for a, b in zip(encrypted, key))
        
        result = decrypted.decode('utf-8', errors='replace')
        if all(32 <= ord(c) < 127 for c in result[:50]) and ' ' in result[:50]:
            logger.debug(f"Successfully decrypted with hardcoded key: {result[:50]}...")
            return result
    except Exception:
        pass
    
    # If all attempts fail, return the original
    logger.debug(f"All decryption attempts failed for: {ciphertext_b64[:20]}...")
    return ciphertext_b64


def get_known_answer_map() -> Dict[str, str]:
    """Get a mapping of known encrypted answers to their decrypted values.
    
    This function maintains a catalog of known encrypted strings that
    couldn't be automatically decrypted, along with their verified
    plaintext values.
    
    Returns:
        Dictionary mapping encrypted strings to their plaintext values.
    """
    return {
        "dFoTn+K+bcdyWg==": "Tooth Rock",
        "ERFIwA==": "1945",
        # Add more mappings as they are discovered during benchmark runs
    }

==> local_deep_research-0.6.5-py3-none-any.whl: local_deep_research/benchmarks/datasets/utils.py <==
"""
Utility functions for dataset handling.

This module provides utility functions for common dataset operations like
decryption, encoding detection, etc.
"""

import base64
import hashlib
import logging
from typing import Dict

logger = logging.getLogger(__name__)


def derive_key(password: str, length: int) -> bytes:
    """Derive a fixed-length key from the password using SHA256."""
    hasher = hashlib.sha256()
    hasher.update(password.encode())
    key = hasher.digest()
    return key * (length // len(key)) + key[: length % len(key)]


def decrypt(ciphertext_b64: str, password: str) -> str:
    """
    Decrypt base64-encoded ciphertext with XOR.
    Uses multiple approaches to handle different encoding formats.
    """
    # Skip decryption for non-encoded strings
    if not isinstance(ciphertext_b64, str) or len(ciphertext_b64) < 8:
        return ciphertext_b64

    # Skip if the string doesn't look like base64
    if not all(
        c in "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/="
        for c in ciphertext_b64
    ):
        return ciphertext_b64

    # Attempt standard decryption
    try:
        encrypted = base64.b64decode(ciphertext_b64)
        key = derive_key(password, len(encrypted))
        decrypted = bytes(a ^ b for a, b in zip(encrypted, key))

        # Check if the result looks like valid text
        result = decrypted.decode("utf-8", errors="replace")

        # Heuristic check - if the decrypted text is mostly ASCII and contains spaces
        if all(32 <= ord(c) < 127 for c in result[:50]) and " " in result[:50]:
            logger.debug(
                f"Successfully decrypted with standard method: {result[:50]}..."
            )
            return result
    except Exception as e:
        logger.debug(f"Standard decryption failed: {str(e)}")

    # Alternative method - try using just the first part of the password
    try:
        if len(password) > 30:
            alt_password = password.split()[0]  # Use first word
            encrypted = base64.b64decode(ciphertext_b64)
            key = derive_key(alt_password, len(encrypted))
            decrypted = bytes(a ^ b for a, b in zip(encrypted, key))

            result = decrypted.decode("utf-8", errors="replace")
            if (
                all(32 <= ord(c) < 127 for c in result[:50])
                and " " in result[:50]
            ):
                logger.debug(
                    f"Successfully decrypted with alternate method 1: {result[:50]}..."
                )
                return result
    except Exception:
        pass

    # Alternative method 2 - try using the GUID part
    try:
        if "GUID" in password:
            guid_part = password.split("GUID")[1].strip()
            encrypted = base64.b64decode(ciphertext_b64)
            key = derive_key(guid_part, len(encrypted))
            decrypted = bytes(a ^ b for a, b in zip(encrypted, key))

            result = decrypted.decode("utf-8", errors="replace")
            if (
                all(32 <= ord(c) < 127 for c in result[:50])
                and " " in result[:50]
            ):
                logger.debug(
                    f"Successfully decrypted with GUID method: {result[:50]}..."
                )
                return result
    except Exception:
        pass

    # Alternative method 3 - hardcoded key for BrowseComp
    try:
        hardcoded_key = "MHGGF2022!"  # Known key for BrowseComp dataset
        encrypted = base64.b64decode(ciphertext_b64)
        key = derive_key(hardcoded_key, len(encrypted))
        decrypted = bytes(a ^ b for a, b in zip(encrypted, key))

        result = decrypted.decode("utf-8", errors="replace")
        if all(32 <= ord(c) < 127 for c in result[:50]) and " " in result[:50]:
            logger.debug(
                f"Successfully decrypted with hardcoded key: {result[:50]}..."
            )
            return result
    except Exception:
        pass

    # If all attempts fail, return the original
    logger.debug(
        f"All decryption attempts failed for: {ciphertext_b64[:20]}..."
    )
    return ciphertext_b64


def get_known_answer_map() -> Dict[str, str]:
    """Get a mapping of known encrypted answers to their decrypted values.

    This function maintains a catalog of known encrypted strings that
    couldn't be automatically decrypted, along with their verified
    plaintext values.

    Returns:
        Dictionary mapping encrypted strings to their plaintext values.
    """
    return {
        "dFoTn+K+bcdyWg==": "Tooth Rock",
        "ERFIwA==": "1945",
        # Add more mappings as they are discovered during benchmark runs
    }
